#!/usr/bin/python
# -*- coding: utf-8 -*-

# 返回类型
ALI_CONTENT_TYPE_XML = ["application/xml;charset=utf-8", "text/xml;charset=utf-8",
                        "application/xml", "text/xml"]
ALI_CONTENT_TYPE_JSON = ["application/json", "text/json"]

# 注册的服务
ALI_API_SERVICE_MNS = "MNS"
ALI_API_SERVICE_OSS = "OSS"
